import { Paper, Stack } from '@suid/material';
import styled from '@suid/material/styles/styled';
import { Component, JSXElement, Show } from 'solid-js';

interface Props {
  title: string | JSXElement;
  content: JSXElement | undefined;
  subTree: JSXElement | undefined;
}

const Item = styled(Paper)(({ theme }) => ({
  ...theme.typography.body2,
  padding: theme.spacing(1),
  textAlign: 'left',
  color: theme.palette.text.secondary,
}));

const Tree: Component<Props> = ({ title, content, subTree }) => {
  return (
    <Stack
      spacing={1}
      direction='column'
      alignItems='center'
      sx={{ width: 'calc(100% - 5px)' }}
    >
      <Item sx={{ width: 'calc(100% - 1px)' }}>
        <div>{title}</div>
        <Show when={content !== undefined}>
          <div>{content}</div>
        </Show>
        <Show when={subTree !== undefined}>
          <div>{subTree}</div>
        </Show>
      </Item>
    </Stack>
  );
};

export default Tree;
